#
# Cookbook Name:: aws_s3_presigned_url
# Library:: helpers
#
# The MIT License (MIT)
#
# Copyright (c) 2015 Maciej Strzelecki
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

require 'aws-sdk'

def aws_s3_presigned_url(
  bucket,
  key,
  expires_in = node['aws_s3_presigned_url']['expires_in'],
  options = {}
)
  access_key_id = options.fetch(
    'access_key_id',
    node['aws_s3_presigned_url']['access_key_id']
  )

  secret_access_key = options.fetch(
    'secret_access_key',
    node['aws_s3_presigned_url']['secret_access_key']
  )

  region = options.fetch(
    'region',
    node['aws_s3_presigned_url']['region']
  )

  client = Aws::S3::Client.new(access_key_id: access_key_id,
                               secret_access_key: secret_access_key,
                               region: region)

  signer = Aws::S3::Presigner.new(client: client)

  signer.presigned_url(:get_object, bucket: bucket, key: key,
                                    expires_in: expires_in)
end
